<?php

$LANG = array(

'L_ID' 														=> '#',
'L_MENU'													=> 'меню',
'L_UNKNOWN_ERROR'											=> 'Неизвестная ошибка',
'L_CONFIRM_DELETE'											=> 'Подтвердите удаление ?',
'L_SAVE_FILE'												=> 'Сохраните файл',
'L_SAVE_FILE_SUCCESSFULLY'									=> 'Файл успешно сохранены',
'L_SAVE_FILE_ERROR'											=> 'Ошибка при сохранении файла',
'L_REPLY'													=> 'ответ',
'L_REPLY_TO'												=> 'ответ',
'L_CANCEL'													=> 'отменить',
'L_DELETE'													=> 'Удалить',
'L_DELETE_FILE' 				    						=> 'Удалить файл',
'L_DELETE_FOLDER'				   							=> 'Удалить папку',
'L_DELETE_SUCCESSFUL'										=> 'Успешное удаление',
'L_DELETE_FILE_ERR'											=> 'Ошибка при удалении файла',
'L_RENAME_FILE_SUCCESSFUL'									=> 'Файл успешно переименован',
'L_RENAME_FILE_ERR'											=> 'Ошибка при обработке файла',
'L_RENAME_FILE'												=> 'Переименуйте файл',
'L_THUMBNAIL'												=> 'миниатюрами (необязательно)',
'L_THUMBNAIL_SELECTION'										=> 'Выбрать Изображение',
'L_THUMBNAIL_TITLE'											=> 'Изображение Название (необязательно)',
'L_THUMBNAIL_ALT'											=> 'Альтернативный текст изображения (необязательно)',
'L_ERR_INVALID_DATE_CREATION'								=> 'Неверный дата создания',
'L_ERR_INVALID_DATE_UPDATE'									=> 'Неверный дате обновления',

# class.plx.admin.php

'L_SAVE_SUCCESSFUL'											=> 'Данные успешно сохранены',
'L_SAVE_ERR'												=> 'Ошибка при сохранении данных',
'L_NO_ENTRY'												=> 'Войти невозможно',
'L_ERR_USER_EMPTY'											=> 'Имя пользователя',
'L_ERR_PASSWORD_EMPTY'										=> 'Пароль',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'							=> 'Неправильное Имя или Пароль',
'L_ERR_INVALID_EMAIL'										=> 'Неправильный адрес электронной почты',
'L_ERR_INVALID_SITE'										=> 'Неправильный URL сайта',
'L_ERR_INVALID_ARTICLE_IDENT'								=> 'Неверный ID статьи',
'L_DEFAULT_NEW_CATEGORY_URL'								=> 'new-category',
'L_DEFAULT_NEW_STATIC_URL'									=> 'new-page',
'L_DEFAULT_NEW_ARTICLE_URL'									=> 'new-article',
'L_ARTICLE_SAVE_SUCCESSFUL'									=> 'Статья успешно создана',
'L_ARTICLE_MODIFY_SUCCESSFUL'								=> 'Статья успешно обновлена',
'L_ARTICLE_DELETE_SUCCESSFUL'								=> 'Статья было успешно удалена',
'L_ARTICLE_SAVE_ERR'										=> 'Статьи не могут быть сохранены',
'L_ARTICLE_DELETE_ERR'										=> 'Ошибка: статья не может быть удалена',
'L_ERR_UNKNOWN_COMMENT'										=> 'Выбранный комментарий не существует',
'L_COMMENT_SAVE_SUCCESSFUL'									=> 'Комментарий был успешно сохранен',
'L_COMMENT_UPDATE_ERR'										=> 'Ошибка во время обновления комментария',
'L_COMMENT_DELETE_SUCCESSFUL'								=> 'Комментарий был успешно удален',
'L_COMMENT_DELETE_ERR'										=> 'Ошибка в удалении комментария',
'L_COMMENT_VALIDATE_SUCCESSFUL'								=> 'Комментарий был успешно проверен',
'L_COMMENT_VALIDATE_ERR'									=> 'Ошибка при проверке',
'L_COMMENT_MODERATE_SUCCESSFUL'								=> 'Успешная модерация',
'L_COMMENT_MODERATE_ERR'									=> 'Ошибка при модерации',
'L_ERR_URL_ALREADY_EXISTS'									=> 'Адрес уже используется. Пожалуйста, измените значение поля \'Адрес\'',

# class.plx.media.php

'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'								=> 'Невозможно создать медиа-папку для текущего пользователя',
'L_PLXMEDIAS_ROOT'											=> 'корневая папка',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'						=> 'Файлы успешно удалены',
'L_PLXMEDIAS_DELETE_FILES_ERR'								=> 'Ошибка при удалении файла',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'						=> 'Файл успешно удален',
'L_PLXMEDIAS_DELETE_FILE_ERR'								=> 'Ошибка при удалении файла',
'L_PLXMEDIAS_DEL_FOLDER_ERR'								=> 'Ошибка во время удаления папки',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'							=> 'Папка успешно удалена',
'L_PLXMEDIAS_NEW_FOLDER_ERR'								=> 'Не удается создать папку',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'							=> 'Папка успешно создана',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'								=> 'Это папка уже существует',
'L_PLXMEDIAS_WRONG_FILESIZE'								=> 'Размер файла больше, чем',
'L_PLXMEDIAS_WRONG_FILEFORMAT'								=> 'Недопустимый тип файла',
'L_PLXMEDIAS_UPLOAD_ERR'									=> 'Ошибка при загрузке файла',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'								=> 'Файл успешно загружен',
'L_PLXMEDIAS_UPLOADS_ERR'									=> 'Ошибка при загрузке файлов',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'							=> 'Файлы успешно загружены',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'							=> 'Файлы перемещены успешно',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'							=> 'Файл успешно перемещен',
'L_PLXMEDIAS_MOVE_FILES_ERR'								=> 'Ошибка при перемещении файлов',
'L_PLXMEDIAS_MOVE_FILE_ERR'									=> 'Ошибка при перемещении файла',
'L_PLXMEDIAS_MOVE_FOLDER'									=> 'Переместить',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'							=> 'Ошибка при обновлении эскиза',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'							=> 'Ошибка при обновлении эскизов',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'						=> 'Эскиз успешно обновлен',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'					=> 'Эскизы успешно обновлены',

# article.php

'L_DEFAULT_NEW_ARTICLE_TITLE'								=> 'Заголовок статьи',
'L_ERR_INVALID_PUBLISHING_DATE'								=> 'Неверная дата публикации',
'L_ERR_UNKNOWN_ARTICLE'										=> 'Статья не существует',
'L_ERR_FORBIDDEN_ARTICLE'									=> 'Вы должны иметь необходимые права на доступ к этой статье!',
'L_BACK_TO_ARTICLES'										=> 'Вернуться к статьям',
'L_ARTICLE_EDITING'											=> 'Редактирование статьи',
'L_ARTICLE_TITLE'											=> 'Название',
'L_ARTICLE_LIST_AUTHORS'									=> 'Автор',
'L_HEADLINE_FIELD'											=> 'Заголовок (необязательно)',
'L_CONTENT_FIELD'											=> 'Содержание ',
'L_LINK_FIELD'												=> 'Ссылка на статью',
'L_LINK_ACCESS'												=> 'Перейти к статье',
'L_LINK_VIEW'												=> 'посмотреть',
'L_ARTICLE_STATUS'											=> 'Статус',
'L_DRAFT'													=> 'Черновик',
'L_PUBLISHED'												=> 'Опубликовано',
'L_AWAITING'												=> 'Ожидание модерации автором блога',
'L_ARTICLE_DATE'											=> 'Дата статьи',
'L_NOW'														=> 'сейчас',
'L_ARTICLE_CATEGORIES'										=> 'Категории',
'L_CATEGORY_HOME_PAGE'										=> 'Главная страница',
'L_NEW_CATEGORY'											=> 'Новая категория',
'L_ARTICLE_TAGS_FIELD'										=> 'Ключевые слова',
'L_ARTICLE_TAGS_FIELD_TITLE'								=> 'Разделяйте теги запятыми',
'L_ARTICLE_TOGGLER_TITLE'									=> 'Список тегов',
'L_NO_TAG'													=> 'Нет тегов',
'L_ALLOW_COMMENTS'											=> 'Разрешить комментарии',
'L_ARTICLE_URL_FIELD'										=> 'Url',
'L_ARTICLE_URL_FIELD_TITLE'									=> 'Поле URL заполнится автоматически после создания статьи',
'L_ARTICLE_TEMPLATE_FIELD'									=> 'Шаблон',
'L_ARTICLE_MANAGE_COMMENTS'									=> 'Управление комментариями',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'							=> 'Управление комментариями к данной статье',
'L_ARTICLE_NEW_COMMENT'										=> 'Создать комментарий',
'L_ARTICLE_NEW_COMMENT_TITLE'								=> 'Создать комментарий к этой статье',
'L_ARTICLE_DELETE_CONFIRM'									=> 'Удалить эту статью?',
'L_ARTICLE_PREVIEW_BUTTON'									=> 'Предварительный просмотр',
'L_ARTICLE_DRAFT_BUTTON'									=> 'Сохранить как черновик',
'L_ARTICLE_PUBLISHING_BUTTON'								=> 'Опубликовать',
'L_ARTICLE_MODERATE_BUTTON'									=> 'Предоставить автору блога на модерацию',
'L_ARTICLE_OFFLINE_BUTTON'									=> 'Выключить (перевести в оффлайн)',
'L_ARTICLE_UPDATE_BUTTON'									=> 'Сохранить',
'L_CATEGORY_ADD_BUTTON'										=> 'Добавить',
'L_ARTICLE_META_DESCRIPTION'								=> 'Мета-тег описания "Description" (необязательно)',
'L_ARTICLE_META_KEYWORDS'									=> 'Мета-тег ключевых слов "Keywords" (необязательно)',
'L_ARTICLE_TITLE_HTMLTAG'									=> 'Мета-тег заголовка страницы "Title" (необязательно)',
'L_ARTICLE_CHAPO_HIDE'										=> 'скрыть',
'L_ARTICLE_CHAPO_DISPLAY'									=> 'показать',
'L_ARTICLE'													=> 'статья',
'L_ARTICLE_ID'												=> 'ID',

# auth.php

'L_AUTH_PAGE_TITLE'											=> 'Страница авторизации',
'L_LOGOUT_SUCCESSFUL'										=> 'Успешный выход',
'L_LOGIN_PAGE'												=> 'Вход в Админпанель',
'L_AUTH_LOGIN_FIELD'										=> 'Логин',
'L_AUTH_PASSWORD_FIELD'										=> 'Пароль',
'L_SUBMIT_BUTTON'											=> 'Войти',
'L_ERR_WRONG_PASSWORD'										=> 'Неправильный логин или пароль',
'L_POWERED_BY'												=> 'Powered by <a href="http://www.pluxml.org">PluXml</a>',
'L_ERR_MAXLOGIN'											=> 'Слишком много неудачных Войти<br />Повторите попытку через% S минут',

#

'L_SORT_ASCENDING_DATE'										=> 'Дата по возрастанию',
'L_SORT_DESCENDING_DATE'									=> 'Дата по убыванию',
'L_SORT_ALPHABETICAL'										=> 'В алфавитном порядке',
'L_SORT_RANDOM'												=> 'алеаторный',
'L_YES'														=> 'Да',
'L_NO'														=> 'Нет',
'L_OK'														=> 'Ok',
'L_NONE1'													=> 'нет',
'L_NONE2'													=> 'отсутствует',

# categories.php

'L_CAT_TITLE'												=> 'Управление категориями',
'L_CAT_LIST_ID'												=> 'ID',
'L_CAT_LIST_ACTIVE'											=> 'Активно',
'L_CAT_LIST_NAME'											=> 'Название категории',
'L_CAT_LIST_URL'											=> 'Url',
'L_CAT_LIST_SORT'											=> 'Сортировка статей',
'L_CAT_LIST_BYPAGE'											=> 'Статей/страниц',
'L_CAT_LIST_ORDER'											=> 'Позиция',
'L_CAT_LIST_MENU'											=> 'Меню',
'L_CATEGORY'												=> 'Категории',
'L_DISPLAY'													=> 'Показ',
'L_HIDE'													=> 'Скрыть',
'L_OPTIONS'													=> 'Настроить',
'L_NEW_CATEGORY'											=> 'Новая категория',
'L_FOR_SELECTION'											=> 'Выбрать...',
'L_CAT_APPLY_BUTTON'										=> 'Изменить список категорий',
'L_CAT_UNKNOWN'												=> 'Неизвестная категория',

# categorie.php

'L_EDITCAT_PAGE_TITLE'										=> 'Редактирование категории',
'L_EDITCAT_DESCRIPTION'										=> 'Описание',
'L_EDITCAT_DISPLAY_HOMEPAGE'								=> 'Показать в этой категории на главной странице',
'L_EDITCAT_TEMPLATE'										=> 'Тема',
'L_EDITCAT_BACK_TO_PAGE'									=> 'Вернуться к категориям',
'L_EDITCAT_UPDATE'											=> 'Обновление этой категории',
'L_EDITCAT_TITLE_HTMLTAG'									=> 'Заголовок для тега "Title" (необязательно)',
'L_EDITCAT_META_DESCRIPTION'								=> 'Мета-тег описания "Description" (необязательно)',
'L_EDITCAT_META_KEYWORDS'									=> 'Мета-тег ключевых слов "Keywords" (необязательно)',

# commentaire.php

'L_COMMENT_ORPHAN'											=> 'нет статьи',
'L_COMMENT_ORPHAN_STATUS'									=> 'не отображается (мы советуем вам удалить этот комментарий',
'L_COMMENT_ARTICLE_LINKED'									=> 'Статья',
'L_COMMENT_ARTICLE_LINKED_TITLE'							=> 'Статьи, связанные с этим комментарием',
'L_COMMENT_OFFLINE'											=> 'выключенных',
'L_COMMENT_ONLINE'											=> 'включенных',
'L_COMMENT_ONLINE_TITLE'									=> 'Опубликованные комментарии',
'L_BACK_TO_ARTICLE_COMMENTS'								=> 'Вернуться к комментарию этой статьи',
'L_BACK_TO_COMMENTS'										=> 'Вернуться к комментарию',
'L_COMMENT_EDITING'											=> 'Редактирование комментария',
'L_COMMENT_AUTHOR_FIELD'									=> 'Автор',
'L_COMMENT_TYPE_FIELD'										=> 'Тип комментарий',
'L_COMMENT_DATE_FIELD'										=> 'Дата и время публикации',
'L_COMMENT_IP_FIELD'										=> 'Ip',
'L_COMMENT_SITE_FIELD'										=> 'Сайт',
'L_COMMENT_EMAIL_FIELD'										=> 'E-mail',
'L_COMMENT_STATUS_FIELD'									=> 'Статус',
'L_COMMENT_LINKED_ARTICLE_FIELD'							=> 'Связанные статьи',
'L_COMMENT_ARTICLE_FIELD'									=> 'Комментарии',
'L_COMMENT_DELETE_CONFIRM'									=> 'Удалить этот комментарий?',
'L_COMMENT_PUBLISH_BUTTON'									=> 'Подтверждение публикации',
'L_COMMENT_OFFLINE_BUTTON'									=> 'Не отображать',
'L_COMMENT_ANSWER_BUTTON'									=> 'Ответить на этот комментарий',
'L_COMMENT_UPDATE_BUTTON'									=> 'Обновить',
'L_COMMENT_WRITTEN_BY'										=> 'Автор',
'L_ERR_CATEGORY_ALREADY_EXISTS'								=> 'Название категории уже используется',

# sous_navigation/commentaires.php

'L_COMMENT_NEW_COMMENT_TITLE'								=> 'Создать новый комментарий к этой статье',
'L_COMMENT_NEW_COMMENT'										=> 'Создать новый комментарий',

# commentaire_new.php

'L_ERR_ANSWER_UNKNOWN_COMMENT'								=> 'Комментарий, на который Вы пытаетесь ответить, больше не существует!',
'L_ERR_ANSWER_OFFLINE_COMMENT'								=> 'Вы не можете ответить на этот комментарий!',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'								=> 'Этой статьи не существует, вы не можете комментировать!',
'L_ERR_CREATING_COMMENT'									=> 'Произошла ошибка при создании комментария',
'L_CREATING_COMMENT_SUCCESSFUL'								=> 'Комментарий успешно создан',
'L_CREATE_NEW_COMMENT'										=> 'Написать комментарий',
'L_COMMENT_SAVE_BUTTON'										=> 'Сохранить',
'L_ARTICLE_COMMENTS_LIST'									=> 'Комментарии к статье (от новых к старым)',
'L_COMMENT_ANSWER_TITLE'									=> 'Ответить на этот комментарий',
'L_COMMENT_ANSWER'											=> 'Ответ',

# comments.php

'L_COMMENTS_ARTICLE_SCOPE'									=> 'Статья',
'L_COMMENTS_GLOBAL_SCOPE'									=> 'весь сайт',

'L_COMMENTS_LIST_DATE'										=> 'Дата',
'L_COMMENTS_LIST_AUTHOR'									=> 'Автор',
'L_COMMENTS_LIST_MESSAGE'									=> 'Сообщение',
'L_COMMENTS_LIST_ACTION'									=> 'Действие',
'L_COMMENT_EDIT'											=> 'Изменить',
'L_COMMENT_EDIT_TITLE'										=> 'Изменить этот комментарий',
'L_COMMENT_DELETE'											=> 'Удалить',
'L_COMMENT_OFFLINE_FEEDS_TITLE'								=> 'RSS-поток для выключенных комментариев',
'L_COMMENT_OFFLINE_FEEDS'									=> 'Выключенные комментарии',
'L_COMMENT_ONLINE_FEEDS_TITLE'								=> 'RSS-поток для включенных комментариев',
'L_COMMENT_ONLINE_FEEDS'									=> 'Включенные комментарии',
'L_COMMENTS_PRIVATE_FEEDS'									=> 'Приватный поток',

'L_COMMENTS_ONLINE_LIST'									=> 'Список опубликованных комментариев',
'L_COMMENTS_OFFLINE_LIST'									=> 'Комментарии, ожидающие модерации',
'L_COMMENTS_ALL_LIST'										=> 'Список комментариев',

'L_COMMENT_SET_ONLINE'										=> 'Включить',
'L_COMMENT_SET_OFFLINE'										=> 'Выключить',

# index.php

'L_SEARCH'													=> 'Поиск',
'L_SEARCH_PLACEHOLDER'										=> 'ID или название',
'L_ARTICLES_ALL_CATEGORIES'									=> 'Все категории ...',
'L_ALL'														=> 'Всего',
'L_ALL_PUBLISHED'											=> 'Опубликованные',
'L_ALL_DRAFTS'												=> 'Черновики',
'L_ALL_AWAITING_MODERATION'									=> 'Ожидают модерации',
'L_ARTICLES_FILTER_BUTTON'									=> 'Фильтр',
'L_CATEGORIES_TABLE'										=> 'Категории',
'L_SPECIFIC_CATEGORIES_TABLE'								=> 'Особые категории',
'L_ALL_ARTICLES_CATEGORIES_TABLE'							=> 'Все статьи',
'L_ARTICLES_LIST'											=> 'Список статей',
'L_ARTICLE_LIST_DATE'										=> 'Дата',
'L_ARTICLE_LIST_TITLE'										=> 'Название',
'L_ARTICLE_LIST_CATEGORIES'									=> 'Категории',
'L_ARTICLE_LIST_NBCOMS'										=> 'Коммент.',
'L_ARTICLE_LIST_AUTHOR'										=> 'Автор',
'L_ARTICLE_LIST_ACTION'										=> 'Действие',
'L_CATEGORY_HOME'											=> 'Главная',
'L_CATEGORY_DRAFT'											=> 'Черновики',
'L_ARTICLE_VIEW_TITLE'										=> 'Открыть эту статью',
'L_ARTICLE_EDIT'											=> 'Изменить',
'L_ARTICLE_EDIT_TITLE'										=> 'Изменить эту статью',
'L_NEW_COMMENTS_TITLE'										=> 'Комментарии, ожидающие модерации',
'L_VALIDATED_COMMENTS_TITLE'								=> 'Опубликованные комментарии',
'L_NO_ARTICLE'												=> 'Нет статей',

# medias.php

'L_MEDIAS_FILENAME'											=> 'Имя файла',
'L_MEDIAS_TITLE'											=> 'Медиа',
'L_MEDIAS_DIRECTORY'										=> 'Расположение',
'L_MEDIAS_BACK'												=> 'Назад',
'L_MEDIAS_MAX_UPOLAD_FILE'									=> 'Максимальный размер файла',
'L_MEDIAS_MAX_POST_SIZE'									=> 'Максимальный размер данных',
'L_MEDIAS_SUBMIT_FILE'										=> 'Загрузить',
'L_MEDIAS_IMAGES'											=> 'Изображения',
'L_MEDIAS_DOCUMENTS'										=> 'Документы',
'L_MEDIAS_ADD_FILE'											=> 'Добавить файл',
'L_MEDIAS_DELETE_FOLDER'									=> 'Удалить папку',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'							=> 'Удалить папку и ее содержимое %s?',
'L_MEDIAS_FOLDER'											=> 'Файл',
'L_MEDIAS_NEW_FOLDER'										=> 'Новая папка',
'L_MEDIAS_CREATE_FOLDER'									=> 'Создать папку',
'L_MEDIAS_FILESIZE'											=> 'Размер файла',
'L_MEDIAS_DATE'												=> 'Дата',
'L_MEDIAS_DIMENSIONS'										=> 'Разрешения',
'L_MEDIAS_NO_FILE'											=> 'Нет файлов',
'L_MEDIAS_RESIZE'											=> 'Изменение размера изображения',
'L_MEDIAS_RESIZE_NO'										=> 'Размер оригинала',
'L_MEDIAS_THUMBS'											=> 'Создание миниатюр',
'L_MEDIAS_THUMBS_NONE'										=> 'Без эскиза',
'L_MEDIAS_MODIFY'											=> 'Изменить',
'L_MEDIAS_THUMB'											=> 'Эскиз',
'L_MEDIAS_EXTENSION'										=> 'Расширение',
'L_MEDIAS_ADD'												=> 'Добавить',
'L_MEDIAS_ALIGNMENT'										=> 'Выравнивание',
'L_MEDIAS_ALIGN_NONE'										=> 'Нет',
'L_MEDIAS_ALIGN_LEFT'										=> 'Слева',
'L_MEDIAS_ALIGN_CENTER'										=> 'Центр',
'L_MEDIAS_ALIGN_RIGHT'										=> 'Право',
'L_MEDIAS_RECREATE_THUMB'									=> 'Обновить эскизы',
'L_MEDIAS_LINK_COPYCLP'                                     => 'Скопировать ссылку в буфер обмена',
'L_MEDIAS_LINK_COPYCLP_ERR'                                 => 'Невозможно скопировать ссылку в буфер обмена',
'L_MEDIAS_LINK_COPYCLP_DONE'                                => 'ссылка скопирована',
'L_MEDIAS_NEW_NAME'											=> 'Новое имя',
'L_MEDIAS_RENAME'											=> 'Переименование',


# parametres_affichage.php

'L_CONFIG_VIEW_FIELD'										=> 'Настройки',
'L_CONFIG_VIEW_SKIN_SELECT'									=> 'Тема',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'							=> 'Редактирование файлов темы',
'L_CONFIG_VIEW_FILES_EDIT'									=> 'Редактирование файлов темы',
'L_CONFIG_VIEW_SORT'										=> 'Сортировка статей',
'L_CONFIG_VIEW_BYPAGE'										=> 'Статей на странице',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'								=> 'Статей на странице в архиве',
'L_CONFIG_VIEW_BYPAGE_TAGS'									=> 'Статьи на странице в тегах',
'L_CONFIG_VIEW_BYPAGE_ADMIN'								=> 'Статей на странице в Админке',
'L_CONFIG_VIEW_SORT_COMS'									=> 'Сортировка комментариев',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'							=> 'Комментариев на странице в админке',
'L_CONFIG_VIEW_IMAGES'										=> 'Размер изображения (Ширина х Высота)',
'L_CONFIG_VIEW_THUMBS'										=> 'Размер эскизов (Ширина х Высота)',
'L_CONFIG_VIEW_HOMESTATIC'									=> 'Использовать статическую страницу как Главную страницу',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'							=> 'Внимание: Эта страница неактивна',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'							=> 'Загрузка тем <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'								=> 'N° статьи или комментария в RSS-потоке',
'L_CONFIG_VIEW_FEEDS_HEADLINE'								=> 'Отображать только заголовки статей в RSS-потоке',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'							=> 'Поле Заголовка пустое, вместо него отображается содержимое статьи',
'L_CONFIG_VIEW_FEEDS_FOOTER'								=> 'Подпись используется в конце каждой статьи в RSS-потоке',
'L_CONFIG_VIEW_UPDATE'										=> 'Сохранить параметры отображения',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'							=> 'Показать категории без статей',
'L_CONFIG_HOMETEMPLATE'										=> 'Шаблон главной страницы',

# parametres_avances.php

'L_CONFIG_ADVANCED_DESC'									=> 'Расширенные настройки (опытный пользователь)',
'L_CONFIG_ADVANCED_URL_REWRITE'								=> 'Включить URL rewrite',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'						=> 'Внимание .htaccess файл уже присутствует в корневом каталоге вашего PluXml. При включении URL переписывания этот файл будет изменен',
'L_CONFIG_ADVANCED_GZIP'									=> 'Включить GZIP сжатие',
'L_CONFIG_ADVANCED_GZIP_HELP'								=> 'Это cделает возможным сжатие страниц для увеличения пропускной способности, но может увеличить использование процессора',
'L_CONFIG_ADVANCED_CAPCHA'									=> 'Включить анти-спам Capcha',
'L_CONFIG_ADVANCED_ADMIN_KEY'								=> 'Административный ключ (для приватных URL)',
'L_CONFIG_ADVANCED_KEY_HELP'								=> 'Оставьте это поле пустым, чтобы восстановить ключ',
'L_CONFIG_ADVANCED_USERFOLDERS'								=> 'Используйте другую папку средств массовой информации для каждого пользователя',
'L_HELP_SLASH_END'											=> 'Не забудьте слеш / в конце',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'							=> 'Медиа место (папка)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'								=> 'Папка для статей',
'L_CONFIG_ADVANCED_COMS_FOLDER'								=> 'Папка для комментариев',
'L_CONFIG_ADVANCED_STATS_FOLDER'							=> 'Папка для статических страниц',
'L_CONFIG_ADVANCED_THEMES_FOLDER'							=> 'Папка с темами',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'							=> 'Папка с плагинами',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'							=> 'Расположение файлов конфигурации (каталог)',
'L_CONFIG_ADVANCED_UPDATE'									=> 'Сохранить дополнительные настройки',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'								=> 'Место и имя пользовательских файлов CSS области управления (опция)',

# parametres_base.php

'L_CONFIG_BASE_CONFIG_TITLE'								=> 'Основные настройки',
'L_CONFIG_BASE_SITE_TITLE'									=> 'Название сайта',
'L_CONFIG_BASE_SITE_SLOGAN'									=> 'Слоган сайта',
'L_CONFIG_BASE_URL_HELP'									=> 'Не забудьте слеш / в конце',
'L_CONFIG_BASE_DEFAULT_LANG'								=> 'Язык сайта по умолчанию',
'L_CONFIG_BASE_TIMEZONE'									=> 'Часовой пояс',
'L_CONFIG_BASE_ALLOW_COMMENTS'								=> 'Разрешить комментарии',
'L_CONFIG_BASE_MODERATE_COMMENTS'							=> 'Модерация комментариев',
'L_CONFIG_BASE_MODERATE_ARTICLES'							=> 'Модерация статей для профилей Редактор и Издатель',
'L_CONFIG_BASE_UPDATE'										=> 'Сохранить основные настройки',
'L_CONFIG_META_DESCRIPTION'									=> 'Мета-тег описания "Description" (необязательно)',
'L_CONFIG_META_KEYWORDS'									=> 'Мета-тег ключевых слов "Keywords" (необязательно)',

# parametres_edittpl.php

'L_CONFIG_EDITTPL_ERROR_NOTHEME'							=> 'Нет такой темы!',
'L_CONFIG_EDITTPL_TITLE'									=> 'Редактирование темы',
'L_CONFIG_EDITTPL_SELECT_FILE'								=> 'Выберите файл для редактирования:',
'L_CONFIG_EDITTPL_LOAD'										=> 'Загрузить',

# parametres_infos.php

'L_CONFIG_INFOS_TITLE'										=> 'Информация о PluXml',
'L_CONFIG_INFOS_DESCRIPTION'								=> 'Информацио о установленной PluXml, может быть полезна, при необходмости, для восстановления.',
'L_CONFIG_INFOS_NB_CATS'									=> 'N° категорий :',
'L_CONFIG_INFOS_NB_STATICS'									=> 'N° статических страниц :',
'L_CONFIG_INFOS_WRITER'										=> 'N° пользователей за сессию :',
'L_PLUXML_CHECK_VERSION'									=> 'Проверка номера версии PluXml на официальном сайте PluXml.org :',
'L_PLUXML_UPDATE_UNAVAILABLE'								=> 'Невозможно проверить обновление, так как адрес \'allow_url_fopen\' заблокирован на этом компьютере',
'L_PLUXML_UPDATE_ERR'										=> 'Проверка обновления окончилась неудачно по неизвестной причине',
'L_PLUXML_UPTODATE'											=> 'Вы используете последнюю версию PluXml',
'L_PLUXML_UPDATE_AVAILABLE'									=> 'Новая версия PluXml доступна! Вы может скачать ее с',

# parametres_users.php

'L_CONFIG_USERS_TITLE'										=> 'Пользователи',
'L_CONFIG_USER'												=> 'Пользователи',
'L_CONFIG_USERS_ID'											=> 'ID Пользователя',
'L_CONFIG_USERS_ACTIVE'										=> 'Активен',
'L_CONFIG_USERS_ACTION'										=> 'Настройки',
'L_CONFIG_USERS_NEW'										=> 'Новый пользователь',
'L_CONFIG_USERS_UPDATE'										=> 'Сохранить список пользователей',
'L_ERR_LOGIN_ALREADY_EXISTS'								=> 'Такой логин уже используется',
'L_ERR_USERNAME_ALREADY_EXISTS'								=> 'Такое имя пользователя уже используется',

# parametre_plugins.php

'L_BACK_TO_PLUGINS'											=> 'Вернуться на страницу плагинов',
'L_NO_PLUGIN'												=> 'Нет плагина',
'L_PLUGIN_NO_CONFIG'										=> 'Плагин не настроено',
'L_PLUGINS_CSS'												=> 'Css',
'L_PLUGINS_CSS_TITLE'										=> 'Редактирования кода CSS этого плагина',
'L_CONTENT_FIELD_FRONTEND'									=> 'Содержание веб-сайта CSS-файла',
'L_CONTENT_FIELD_BACKEND'									=> 'Css содержимое файла администратор',

# parametres_plugins.php

'L_PLUGINS_TITLE'											=> 'Плагины',
'L_PLUGINS_VERSION'											=> 'Версия',
'L_PLUGINS_AUTHOR'											=> 'Автор',
'L_PLUGINS_ACTIVATE'										=> 'Включить',
'L_PLUGINS_DEACTIVATE'										=> 'Выключить',
'L_PLUGINS_DELETE'											=> 'Удалить',
'L_PLUGINS_DELETE_ERROR'									=> 'Произошла ошибка во время удаления',
'L_PLUGINS_DELETE_SUCCESSFUL'								=> 'Удалено успешно',
'L_PLUGINS_CONFIG'											=> 'Конфигурация',
'L_PLUGINS_CONFIG_TITLE'									=> 'Конфигурация плагина',
'L_PLUGINS_HELP'											=> 'помощь',
'L_PLUGINS_HELP_TITLE'										=> 'Смотрите раздел Использование плагина',
'L_PLUGINS_REQUIREMENTS'									=> 'Системные требования',
'L_PLUGINS_REQUIREMENTS_HELP'								=> 'Доступные и активные плагины',
'L_PLUGINS_REQUIREMENTS_NONE'								=> 'Нет',
'L_PLUGINS_ALPHA_SORT'										=> 'Сортировка по алфавиту плагинов',
'L_PLUGINS_LOADING_SORT'									=> 'Погрузочный ордер',
'L_PLUGINS_ACTION'											=> 'действие',
'L_PLUGINS_APPLY_BUTTON'									=> 'Изменить список плагинов',
'L_PLUGINS_ACTIVE_LIST'										=> 'Активная плагины',
'L_PLUGINS_INACTIVE_LIST'									=> 'Неактивные плагины',

# profil.php

'L_PROFIL_EDIT_TITLE'										=> 'Редактирование профиля',
'L_PROFIL'													=> 'Профиль',
'L_PROFIL_LOGIN'											=> 'Логин',
'L_PROFIL_USER'												=> 'Имя, Фамилия',
'L_PROFIL_MAIL'												=> 'Email адрес',
'L_PROFIL_ADMIN_LANG'										=> 'Язык Административной панели',
'L_PROFIL_INFOS'											=> 'Информация о Вас (отображается под текстом статей)',
'L_PROFIL_UPDATE'											=> 'Изменить Ваш профиль',
'L_PROFIL_CHANGE_PASSWORD'									=> 'Изменение пароля',
'L_PROFIL_PASSWORD'											=> 'Пароль',
'L_PROFIL_CONFIRM_PASSWORD'									=> 'Повторить пароль',
'L_PROFIL_UPDATE_PASSWORD'									=> 'Изменить пароль',

# statique.php

'L_STATIC_BACK_TO_PAGE'										=> 'Вернуться к списку статических страниц',
'L_STATIC_UNKNOWN_PAGE'										=> 'Эта статическая страница не существует!',
'L_STATIC_TITLE'											=> 'Изменить исходный код статической страницы',
'L_STATIC_VIEW_PAGE'										=> 'Просмотр страницы',
'L_STATIC_ON_SITE'											=> 'на сайте',
'L_STATIC_UPDATE'											=> 'Сохранить эту страницу',
'L_STATIC_TITLE_HTMLTAG'									=> 'Заголовок для тега "Title" (необязательно)',
'L_STATIC_META_DESCRIPTION'									=> 'Мета-тег описания "Description" этой статической страницы (необязательно)',
'L_STATIC_META_KEYWORDS'									=> 'Мета-тег ключевых слов "Keywords" этой статической страницы (необязательно)',

# statiques.php

'L_STATICS_PAGE_TITLE'										=> 'Создание и редактирование статических страниц',
'L_STATICS_ID'												=> 'ID',
'L_STATICS_GROUP'											=> 'Группа',
'L_STATICS_TITLE'											=> 'Название',
'L_STATICS_URL'												=> 'Url',
'L_STATICS_ACTIVE'											=> 'Активно',
'L_STATICS_ORDER'											=> 'Позиция',
'L_STATICS_MENU'											=> 'Меню',
'L_STATICS_ACTION'											=> 'Действие',
'L_STATICS_TEMPLATE_FIELD'									=> 'Тема',
'L_STATICS_PAGE_HOME'										=> 'Сделать Главной страницей',
'L_STATICS_HOME_PAGE'										=> 'Главной<br />страница',
'L_PAGE'													=> 'Страница',
'L_VIEW'													=> 'Показать',
'L_STATICS_SRC_TITLE'										=> 'Изменение исходного кода этой страницы',
'L_STATICS_SRC'												=> 'Редактировать',
'L_STATICS_NEW_PAGE'										=> 'Новая страница',
'L_STATICS_UPDATE'											=> 'Сохранить список статических страниц',
'L_ERR_STATIC_ALREADY_EXISTS'								=> 'Такой заголовок страницы уже используется',

# top.php
'L_PROFIL_ADMIN'											=> 'Администратор',
'L_PROFIL_MANAGER'											=> 'Менеджер',
'L_PROFIL_MODERATOR'										=> 'Модератор',
'L_PROFIL_EDITOR'											=> 'Редактор',
'L_PROFIL_WRITER'											=> 'Автор',
'L_ADMIN'													=> 'Администрирование',
'L_LOGIN'													=> 'Вы зашли как',
'L_ADMIN_LOGOUT'											=> 'Выйти',
'L_ADMIN_LOGOUT_TITLE'										=> 'Завершить администрирование',
'L_BACK_TO_SITE'											=> 'Главная',
'L_BACK_TO_SITE_TITLE'										=> 'Вернуться на главную страницу',
'L_BACK_TO_BLOG'											=> 'Блог',
'L_BACK_TO_BLOG_TITLE'										=> 'Вернуться к блогу',
'L_MENU_ARTICLES'											=> 'Статьи',
'L_MENU_ARTICLES_TITLE'										=> 'Список и редактирование статей',
'L_MENU_NEW_ARTICLES'										=> 'Новая статья',
'L_MENU_NEW_ARTICLES_TITLE'									=> 'Новая статья',
'L_MENU_STATICS_TITLE'										=> 'Список и редактирование статических страниц',
'L_MENU_STATICS'											=> 'Статические страницы',
'L_MENU_COMMENTS_TITLE'										=> 'Список и редактирование комментариев',
'L_MENU_COMMENTS'											=> 'Комментарии',
'L_MENU_MEDIAS_TITLE'										=> 'Загрузить и вставить изображение',
'L_MENU_MEDIAS'												=> 'Медиа',
'L_MENU_CATEGORIES_TITLE'									=> 'Создание, управление и редактирование категорий',
'L_MENU_CATEGORIES'											=> 'Категории',
'L_MENU_CONFIG_TITLE'										=> 'Конфигурация PluXml',
'L_MENU_CONFIG'												=> 'Настройки',
'L_MENU_PROFIL_TITLE'										=> 'Управление профилем пользователя',
'L_MENU_PROFIL'												=> 'Профиль',
'L_WARNING_INSTALLATION_FILE'								=> 'Внимание! Файл install.php все еще находится в корневой папке PluXml.<br />Из соображений безопасности настоятельно рекомендуем <a class="lnkdelete" href="?del=install">удалить</a> его.',

# user.php
'L_USER_UNKNOWN'											=> 'Неизвестный пользователь',
'L_USER_LANG'												=> 'Язык, используемый в Администрировании',
'L_USER_MAIL'												=> 'Email адрес',
'L_USER_INFOS'												=> 'Информация',
'L_USER_UPDATE'												=> 'Обновление этого пользователя',
'L_USER_PAGE_TITLE'											=> 'Редактирование параметров пользователя',
'L_USER_BACK_TO_PAGE'										=> 'Вернуться к списку пользователей',

#

'L_MENU_CONFIG_BASE_TITLE'									=> 'Изменение конфигурации',
'L_MENU_CONFIG_BASE'										=> 'Конфигурация сайта --',
'L_MENU_CONFIG_VIEW_TITLE'									=> 'Настройки отображения сайта',
'L_MENU_CONFIG_VIEW'										=> 'Отображение сайта --',
'L_MENU_CONFIG_USERS_TITLE'									=> 'Управление учетными записями пользователей',
'L_MENU_CONFIG_USERS'										=> 'Пользователи --',
'L_MENU_CONFIG_ADVANCED_TITLE'								=> 'Дополнительные настройки',
'L_MENU_CONFIG_ADVANCED'									=> 'Дополнительные настройки --',
'L_MENU_CONFIG_INFOS_TITLE'									=> 'Информация о сайте',
'L_MENU_CONFIG_INFOS'										=> 'Информация --',
'L_MENU_CONFIG_PLUGINS_TITLE'								=> 'Плагины',
'L_MENU_CONFIG_PLUGINS'										=> 'Плагины --',
'L_THEMES'													=> 'Темы',
'L_THEMES_TITLE'											=> 'Управление темы',
'L_HELP'													=> 'помощь',
'L_HELP_TITLE'												=> 'См помощь',
'L_BACK_TO_THEMES'											=> 'Вернуться к темам страницы',
'L_CONFIG_THEME_UPDATE'										=> 'Изменить стиль',
);
?>